@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
 import re
 import inspect
 
 from django import forms
+from django.forms.models import inlineformset_factory, BaseInlineFormSet
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
@@ -14,25 +14,56 @@ try:
     from django.utils.timezone import now as tznow
 except ImportError:
     import datetime
+
     tznow = datetime.datetime.now
 
-from pybb.models import Topic, Post, Profile, Attachment
+from pybb.models import Topic, Post, Profile, Attachment, PollAnswer
 from pybb import defaults
 
 
 class AttachmentForm(forms.ModelForm):
     class Meta(object):
         model = Attachment
-        fields = ('file',)
+        fields = ('file', )
 
     def clean_file(self):
         if self.cleaned_data['file'].size > defaults.PYBB_ATTACHMENT_SIZE_LIMIT:
-                raise forms.ValidationError(_('Attachment is too big'))
+            raise forms.ValidationError(_('Attachment is too big'))
         return self.cleaned_data['file']
 
-    
+AttachmentFormSet = inlineformset_factory(Post, Attachment, extra=1, form=AttachmentForm)
+
+
+class PollAnswerForm(forms.ModelForm):
+    class Meta:
+        model = PollAnswer
+        fields = ('text', )
+
+
+class BasePollAnswerFormset(BaseInlineFormSet):
+    def clean(self):
+        if any(self.errors):
+            return
+        forms_cnt = len(self.initial_forms) + len([form for form in self.extra_forms if form.has_changed()]) -\
+                    len(self.deleted_forms)
+        if forms_cnt > defaults.PYBB_POLL_MAX_ANSWERS:
+            raise forms.ValidationError(
+                _('You can''t add more than %s answers for poll' % defaults.PYBB_POLL_MAX_ANSWERS))
+        if forms_cnt < 2:
+            raise forms.ValidationError(_('Add two or more answers for this poll'))
+
+
+PollAnswerFormSet = inlineformset_factory(Topic, PollAnswer, extra=2, max_num=defaults.PYBB_POLL_MAX_ANSWERS,
+    form=PollAnswerForm, formset=BasePollAnswerFormset)
+
+
 class PostForm(forms.ModelForm):
     name = forms.CharField(label=_('Subject'))
+    poll_type = forms.TypedChoiceField(label=_('Poll type'), choices=Topic.POLL_TYPE_CHOICES, coerce=int)
+    poll_question = forms.CharField(
+        label=_('Poll question'),
+        required=False,
+        widget=forms.Textarea(attrs={'class': 'no-markitup'}))
 
     class Meta(object):
         model = Post
@@ -48,17 +79,19 @@ class PostForm(forms.ModelForm):
         self.forum = kwargs.pop('forum', None)
         if not (self.topic or self.forum or ('instance' in kwargs)):
             raise ValueError('You should provide topic, forum or instance')
-        #Handle topic subject if editing topic head
+            #Handle topic subject, poll type and question if editing topic head
         if ('instance' in kwargs) and kwargs['instance'] and (kwargs['instance'].topic.head == kwargs['instance']):
             kwargs.setdefault('initial', {})['name'] = kwargs['instance'].topic.name
+            kwargs.setdefault('initial', {})['poll_type'] = kwargs['instance'].topic.poll_type
+            kwargs.setdefault('initial', {})['poll_question'] = kwargs['instance'].topic.poll_question
 
         super(PostForm, self).__init__(**kwargs)
 
-        self.fields.keyOrder = ['name', 'body']
-
+        # remove topic specific fields
         if not (self.forum or (self.instance.pk and (self.instance.topic.head == self.instance))):
-            self.fields['name'].widget = forms.HiddenInput()
-            self.fields['name'].required = False
+            del self.fields['name']
+            del self.fields['poll_type']
+            del self.fields['poll_question']
 
         self.available_smiles = defaults.PYBB_SMILES
         self.smiles_prefix = defaults.PYBB_SMILES_PREFIX
@@ -72,7 +105,14 @@ class PostForm(forms.ModelForm):
         for cleaner in defaults.PYBB_BODY_CLEANERS:
             body = cleaner(user, body)
         return body
-        
+
+    def clean(self):
+        poll_type = self.cleaned_data.get('poll_type', None)
+        poll_question = self.cleaned_data.get('poll_question', None)
+        if poll_type is not None and poll_type != Topic.POLL_TYPE_NONE and not poll_question:
+            raise forms.ValidationError(_('Poll''s question is required when adding a poll'))
+
+        return self.cleaned_data
 
     def save(self, commit=True):
         if self.instance.pk:
@@ -81,29 +121,36 @@ class PostForm(forms.ModelForm):
                 post.user = self.user
             if post.topic.head == post:
                 post.topic.name = self.cleaned_data['name']
+                post.topic.poll_type = self.cleaned_data['poll_type']
+                post.topic.poll_question = self.cleaned_data['poll_question']
                 post.topic.updated = tznow()
                 post.topic.save()
             post.save()
             return post
         allow_post = True
         if defaults.PYBB_PREMODERATION:
-                allow_post = defaults.PYBB_PREMODERATION(self.user, self.cleaned_data['body'])
+            allow_post = defaults.PYBB_PREMODERATION(self.user, self.cleaned_data['body'])
         if self.forum:
-            topic = Topic(forum=self.forum,
-                          user=self.user,
-                          name=self.cleaned_data['name'])
+            topic = Topic(
+                forum=self.forum,
+                user=self.user,
+                name=self.cleaned_data['name'],
+                poll_type=self.cleaned_data['poll_type'],
+                poll_question=self.cleaned_data['poll_question'],
+            )
             if not allow_post:
                 topic.on_moderation = True
             topic.save()
         else:
             topic = self.topic
         post = Post(topic=topic, user=self.user, user_ip=self.ip,
-                    body=self.cleaned_data['body'])
+            body=self.cleaned_data['body'])
         if not allow_post:
             post.on_moderation = True
         post.save()
         return post
 
+
 class AdminPostForm(PostForm):
     """
     Superusers can post messages from any user and from any time
@@ -117,14 +164,13 @@ class AdminPostForm(PostForm):
         if 'instance' in kwargs and kwargs['instance']:
             kwargs.setdefault('initial', {}).update({'login': kwargs['instance'].user.username})
         super(AdminPostForm, self).__init__(**kwargs)
-        self.fields.keyOrder = ['name', 'login', 'body']
 
     def save(self, *args, **kwargs):
         try:
             self.user = User.objects.filter(username=self.cleaned_data['login']).get()
         except User.DoesNotExist:
             self.user = User.objects.create_user(self.cleaned_data['login'],
-                                                 '%s@example.com' % self.cleaned_data['login'])
+                '%s@example.com' % self.cleaned_data['login'])
         return super(AdminPostForm, self).save(*args, **kwargs)
 
 try:
@@ -164,3 +210,27 @@ class UserSearchForm(forms.Form):
             return qs.filter(username__contains=query)
         else:
             return qs
+
+
+class PollForm(forms.Form):
+    def __init__(self, topic,  *args, **kwargs):
+        self.topic = topic
+
+        super(PollForm, self).__init__(*args, **kwargs)
+
+        qs = PollAnswer.objects.filter(topic=topic)
+        if topic.poll_type == Topic.POLL_TYPE_SINGLE:
+            self.fields['answers'] = forms.ModelChoiceField(
+                label='', queryset=qs, empty_label=None,
+                widget=forms.RadioSelect())
+        elif topic.poll_type == Topic.POLL_TYPE_MULTIPLE:
+            self.fields['answers'] = forms.ModelMultipleChoiceField(
+                label='', queryset=qs,
+                widget=forms.CheckboxSelectMultiple())
+
+    def clean_answers(self):
+        answers = self.cleaned_data['answers']
+        if self.topic.poll_type == Topic.POLL_TYPE_SINGLE:
+            return [answers]
+        else:
+            return answers
